==> fim-0.6-trunk.tar.gz: fim-0.6-trunk/src/version.h <==
"+FIM_ALLOW_LOADER_STRING_SPECIFICATION  "
"+FIM_AUTHOR  "
"+FIM_AUTHOR_EMAIL  "
"+FIM_AUTHOR_NAME  "
"+FIM_AUTOCMDS  "
"+FIM_AUTOSKIP_FAILED  "
"+FIM_BOZ_PATCH  "
"+FIM_CHECK_DUPLICATES  "
"+FIM_CHECK_FILE_EXISTENCE  "
"+FIM_COMMAND_AUTOCOMPLETION  "
"+FIM_CONFIGURATION  "
"+FIM_DEFAULT_CONFIG  "
"+FIM_DEFAULT_CONFIGURATION  "
"+FIM_DEFAULT_KEY_CONFIG  "
"+FIM_EXPERIMENTAL_ROTATION  "
"+FIM_HANDLE_GIF  "
"+FIM_HANDLE_TIFF  "
"+FIM_ITERATED_COMMANDS  "
"+FIM_LINUX_CONSOLEFONTS_DIR_SCAN  "
"+FIM_NAMESPACES  "
"+FIM_NOFB  "
"+FIM_PIPE_IMAGE_READ  "
"+FIM_RANDOM  "
"+FIM_READ_DIRS  "
"+FIM_READ_STDIN  "
"+FIM_READ_STDIN_IMAGE  "
"+FIM_RECORDING  "
"+FIM_RECURSIVE_DIRS  "
"+FIM_REMOVE_FAILED  "
"+FIM_SKIP_KNOWN_FILETYPES  "
"+FIM_SWITCH_FIXUP  "
"+FIM_TMP_FILENAME  "
"+FIM_TRY_INKSCAPE  "
"+FIM_TRY_XFIG  "
"+FIM_USE_CXX_STD  "
"+FIM_USE_READLINE  "
"+FIM_USE_ZCAT  "
"+FIM_VERSION  "
"+FIM_WANT_CUSTOM_INFO_STATUS_BAR  "
"+FIM_WANT_FILENAME_MARK_AND_DUMP  "
"+FIM_WANT_FONT_MAGNIFY_FACTOR  "
"+FIM_WANT_HARDCODED_FONT  "
"+FIM_WANT_LONG_INT  "
"+FIM_WANT_RAW_BITS_RENDERING  "
"+FIM_WANT_SEEK_MAGIC  "
"+FIM_WANT_TEXT_RENDERING  "
"+FIM_WINDOWS  "
"+FIM_WITH_AALIB  "
"+FIM_WITH_ARCHIVE  "
"+FIM_WITH_BMP  "
"+FIM_WITH_CACALIB  "
"+FIM_WITH_LIBEXIF  "
"+FIM_WITH_LIBIMLIB2  "
"+FIM_WITH_LIBJASPER  "
"+FIM_WITH_LIBPNG  "
"+FIM_WITH_LIBSDL  "
"+FIM_WITH_LIBXYZ  "
"+FIM_WITH_PCX  "
"\n"
"FIM_AUTHOR = \"Michele Martone <dezperado _CUT_ autistici _CUT_ org>\"\n"
"FIM_AUTHOR_EMAIL = \"<dezperado _CUT_ autistici _CUT_ org>\"\n"
"FIM_AUTHOR_NAME = \"Michele Martone\"\n"
"FIM_CONFIGURATION = \"./configure CXXFLAGS=-O2 -pipe -I/home/dez/Downloads/tmp/code/poppler-0.24.2 -I/home/dez/Downloads/tmp/code/poppler-0.24.2/poppler -I/opt/librsb-debug/include/ -Wall -Wredundant-decls -Wno-switch -Wdisabled-optimization -Wpointer-arith   -fstack-protector --param=ssp-buffer-size=4 -Wformat -Werror=format-security  -msse2 -march=native   --enable-aa --enable-djvu --enable-ps --enable-imlib2 --enable-xyz --enable-archive --disable-pdf --disable-poppler --enable-cacalib --enable-seek-magic --enable-long-int-vars --disable-paths-in-man --enable-jasper --disable-convert --with-font-magnifying-factor=0 --enable-matrices-rendering LIBS= -L/opt/librsb-debug/lib /opt/librsb-debug/lib/librsb.a -lm -lhwloc -lz\"\n"
"FIM_TMP_FILENAME = \"\"\n"
"FIM_VERSION = \"0.6-trunk\"\n"
"-FIM_BIG_ENDIAN  "
"-FIM_CACHE_DEBUG  "
"-FIM_DEFAULT_CONSOLEFONT  "
"-FIM_KEEP_BROKEN_CONSOLE  "
"-FIM_NOFIMRC  "
"-FIM_NOHISTORY  "
"-FIM_PATHS_IN_MAN  "
"-FIM_SMART_COMPLETION  "
"-FIM_TRY_CONVERT  "
"-FIM_TRY_DIA  "
"-FIM_TRY_XCFTOPNM  "
"-FIM_USE_DESIGNATED_INITIALIZERS  "
"-FIM_WANTS_SLOW_RESIZE  "
"-FIM_WANT_EXIFTOOL  "
"-FIM_WANT_FB_CONSOLE_SWITCH_WHILE_LOADING  "
"-FIM_WANT_NOSCRIPTING  "
"-FIM_WANT_NO_OUTPUT_CONSOLE  "
"-FIM_WANT_STATIC_BINARY  "
"-FIM_WANT_UNICODE  "
"-FIM_WITH_NO_FRAMEBUFFER  "
"-FIM_WITH_UFRAW  "
"\nCXXFLAGS=-O2 -pipe -I/home/dez/Downloads/tmp/code/poppler-0.24.2 -I/home/dez/Downloads/tmp/code/poppler-0.24.2/poppler -I/opt/librsb-debug/include/ -Wall -Wredundant-decls -Wno-switch -Wdisabled-optimization -Wpointer-arith -fstack-protector --param=ssp-buffer-size=4 -Wformat -Werror=format-security -msse2 -march=native -I/usr/local/include/libpng16 -I/usr/include -I/usr/include/SDL -D_GNU_SOURCE=1 -D_REENTRANT\n"

==> fim-0.7-trunk.tar.gz: fim-0.7-trunk/src/version.h <==
"+FIM_ALLOW_LOADER_STRING_SPECIFICATION  "
"+FIM_AUTHOR  "
"+FIM_AUTHOR_EMAIL  "
"+FIM_AUTHOR_NAME  "
"+FIM_AUTOCMDS  "
"+FIM_AUTOSKIP_FAILED  "
"+FIM_BOZ_PATCH  "
"+FIM_CHECK_DUPLICATES  "
"+FIM_CHECK_FILE_EXISTENCE  "
"+FIM_COMMAND_AUTOCOMPLETION  "
"+FIM_CONFIGURATION  "
"+FIM_DEFAULT_CONFIG  "
"+FIM_DEFAULT_CONFIGURATION  "
"+FIM_DEFAULT_CONSOLEFONT  "
"+FIM_DEFAULT_KEY_CONFIG  "
"+FIM_EXPERIMENTAL_ROTATION  "
"+FIM_HANDLE_GIF  "
"+FIM_HANDLE_TIFF  "
"+FIM_HAS_TIMEOUT  "
"+FIM_ITERATED_COMMANDS  "
"+FIM_LINUX_CONSOLEFONTS_DIR_SCAN  "
"+FIM_NAMESPACES  "
"+FIM_NOFB  "
"+FIM_PATHS_IN_MAN  "
"+FIM_PIPE_IMAGE_READ  "
"+FIM_RANDOM  "
"+FIM_READ_DIRS  "
"+FIM_READ_STDIN  "
"+FIM_READ_STDIN_IMAGE  "
"+FIM_RECORDING  "
"+FIM_RECURSIVE_DIRS  "
"+FIM_REMOVE_FAILED  "
"+FIM_SKIP_KNOWN_FILETYPES  "
"+FIM_SMART_COMPLETION  "
"+FIM_SWITCH_FIXUP  "
"+FIM_TMP_FILENAME  "
"+FIM_TRY_CONVERT  "
"+FIM_TRY_DIA  "
"+FIM_TRY_INKSCAPE  "
"+FIM_TRY_XFIG  "
"+FIM_USE_READLINE  "
"+FIM_USE_ZCAT  "
"+FIM_VERSION  "
"+FIM_WANT_CUSTOM_INFO_STATUS_BAR  "
"+FIM_WANT_FILENAME_MARK_AND_DUMP  "
"+FIM_WANT_FONT_MAGNIFY_FACTOR  "
"+FIM_WANT_HARDCODED_FONT  "
"+FIM_WANT_LONG_INT  "
"+FIM_WANT_RAW_BITS_RENDERING  "
"+FIM_WANT_SEEK_MAGIC  "
"+FIM_WANT_TEXT_RENDERING  "
"+FIM_WINDOWS  "
"+FIM_WITH_AALIB  "
"+FIM_WITH_ARCHIVE  "
"+FIM_WITH_BMP  "
"+FIM_WITH_DEBUG  "
"+FIM_WITH_LIBCACA  "
"+FIM_WITH_LIBEXIF  "
"+FIM_WITH_LIBIMLIB2  "
"+FIM_WITH_LIBPNG  "
"+FIM_WITH_LIBSDL  "
"+FIM_WITH_PCX  "
"\n"
"FIM_AUTHOR = \"Michele Martone <dezperado _CUT_ autistici _CUT_ org>\"\n"
"FIM_AUTHOR_EMAIL = \"<dezperado _CUT_ autistici _CUT_ org>\"\n"
"FIM_AUTHOR_NAME = \"Michele Martone\"\n"
"FIM_CONFIGURATION = \"./configure CXX=g++ CXXFLAGS=-O2 -pipe -std=c++17 -Werror=all -Wno-error=multistatement-macros -Wno-error=unused-value -Wno-error=format-truncation --enable-pdf --enable-poppler --enable-debug --enable-aa --enable-caca --enable-imlib2 --with-default-consolefont=/usr/share/consolefonts/Lat15-Terminus16.psf.gz --enable-graphicsmagick --enable-archive\"\n"
"FIM_DEFAULT_CONSOLEFONT = \"/usr/share/consolefonts/Lat15-Terminus16.psf.gz\"\n"
"FIM_TMP_FILENAME = \"\"\n"
"FIM_VERSION = \"0.7-trunk\"\n"
"-FIM_BIG_ENDIAN  "
"-FIM_CACHE_DEBUG  "
"-FIM_KEEP_BROKEN_CONSOLE  "
"-FIM_NOFIMRC  "
"-FIM_NOHISTORY  "
"-FIM_TRY_XCFTOPNM  "
"-FIM_USE_DESIGNATED_INITIALIZERS  "
"-FIM_WANTS_SLOW_RESIZE  "
"-FIM_WANT_EXIFTOOL  "
"-FIM_WANT_FB_CONSOLE_SWITCH_WHILE_LOADING  "
"-FIM_WANT_NOSCRIPTING  "
"-FIM_WANT_NO_OUTPUT_CONSOLE  "
"-FIM_WANT_STATIC_BINARY  "
"-FIM_WITH_LIBJASPER  "
"-FIM_WITH_LIBXYZ  "
"-FIM_WITH_NO_FRAMEBUFFER  "
"-FIM_WITH_UFRAW  "
"\nCXXFLAGS=-O2 -pipe -std=c++17 -Werror=all -Wno-error=multistatement-macros -Wno-error=unused-value -Wno-error=format-truncation -I/usr/include/glib-2.0 -I/usr/lib/x86_64-linux-gnu/glib-2.0/include -I/usr/include/poppler -DFIM_LIBPOPPLER_VERSION_MAYBE= -I/usr/include/libpng16 -I/usr/include -I/usr/include/SDL -D_GNU_SOURCE=1 -D_REENTRANT -g -I/usr/include/\n"
